@@ -81,6 +81,7 @@ struct flb_tail_config *flb_tail_config_create(struct flb_input_instance *ins,
     int sec;
     int i;
     long nsec;
+    char *name;
     const char *tmp;
     struct flb_tail_config *ctx;
 
@@ -381,6 +382,27 @@ struct flb_tail_config *flb_tail_config_create(struct flb_input_instance *ins,
 #endif
 
 #ifdef FLB_HAVE_METRICS
+    name = (char *) flb_input_name(ins);
+
+    ctx->cmt_files_opened = cmt_counter_create(ins->cmt,
+                                               "fluentbit", "input",
+                                               "files_opened_total",
+                                               "Total number of opened files",
+                                               1, (char *[]) {name});
+
+    ctx->cmt_files_closed = cmt_counter_create(ins->cmt,
+                                               "fluentbit", "input",
+                                               "files_closed_total",
+                                               "Total number of closed files",
+                                               1, (char *[]) {name});
+
+    ctx->cmt_files_rotated = cmt_counter_create(ins->cmt,
+                                                "fluentbit", "input",
+                                                "files_rotated_total",
+                                                "Total number of rotated files",
+                                                1, (char *[]) {name});
+
+    /* OLD metrics */
     flb_metrics_add(FLB_TAIL_METRIC_F_OPENED,
                     "files_opened", ctx->ins->metrics);
     flb_metrics_add(FLB_TAIL_METRIC_F_CLOSED,
