@@ -36,6 +36,7 @@
 #include <fluent-bit/flb_config.h>
 #include <fluent-bit/flb_engine.h>
 #include <fluent-bit/flb_engine_dispatch.h>
+#include <fluent-bit/flb_network.h>
 #include <fluent-bit/flb_task.h>
 #include <fluent-bit/flb_router.h>
 #include <fluent-bit/flb_http_server.h>
@@ -503,9 +504,14 @@ int flb_engine_start(struct flb_config *config)
     struct mk_event *event;
     struct mk_event_loop *evl;
     struct flb_sched *sched;
+    struct flb_net_dns dns_ctx;
 
     /* Initialize the networking layer */
-    flb_net_init();
+    flb_net_lib_init();
+
+    flb_net_ctx_init(&dns_ctx);
+    flb_net_dns_ctx_init();
+    flb_net_dns_ctx_set(&dns_ctx);
 
     /* Create the event loop and set it in the global configuration */
     evl = mk_event_loop_create(256);
@@ -664,7 +670,7 @@ int flb_engine_start(struct flb_config *config)
      */
     ret = flb_sched_timer_cb_create(config->sched,
                                     FLB_SCHED_TIMER_CB_PERM,
-                                    1500, cb_engine_sched_timer, config);
+                                    1500, cb_engine_sched_timer, config, NULL);
     if (ret == -1) {
         flb_error("[engine] could not schedule permanent callback");
         return -1;
@@ -756,6 +762,7 @@ int flb_engine_start(struct flb_config *config)
 
         /* Cleanup functions associated to events and timers */
         if (config->is_running == FLB_TRUE) {
+            flb_net_dns_lookup_context_cleanup(&dns_ctx);
             flb_sched_timer_cleanup(config->sched);
             flb_upstream_conn_pending_destroy_list(&config->upstreams);
 
